pub struct State {
pub max_open: u64,
pub connections: u64,
pub in_use: u64,
pub idle: u64,
pub wait_count: u64,
pub wait_duration: Duration,
pub max_idle_closed: u64,
pub max_lifetime_closed: u64,
}Expand description
Information about the state of a Pool.
Fields
max_open: u64Maximum number of open connections to the database
connections: u64The number of established connections both in use and idle.
in_use: u64The number of connections currently in use.
idle: u64The number of idle connections.
wait_count: u64The total number of connections waited for.
wait_duration: DurationThe total time blocked waiting for a new connection.
max_idle_closed: u64The total number of connections closed due to max_idle.
max_lifetime_closed: u64The total number of connections closed due to max_lifetime.